docker

package
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 22, 2025 License: MIT Imports: 11 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CleanCache

func CleanCache()

CleanCache deletes all files in the cache directory

func DeleteImage

func DeleteImage(cli *client.Client, imageName string)

func DeleteImages

func DeleteImages(grepPattern string)

DeleteImages deletes the selected Docker images

func ExportImage

func ExportImage(cli *client.Client, imageName, destination string)

func ExportImages

func ExportImages(destination string)

ExportImages exports the selected Docker images to a local destination

func ImportImagesFromSource

func ImportImagesFromSource(source string, grepPattern string)

ImportImagesFromSource imports Docker images from a specified source file or directory

Types

This section is empty.

Jump to