Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DeleteImage ¶
func DeleteImages ¶
func DeleteImages(grepPattern string)
DeleteImages deletes the selected Docker images
func ExportImage ¶
func ExportImages ¶
func ExportImages(destination string)
ExportImages exports the selected Docker images to a local destination
func ImportImagesFromSource ¶
ImportImagesFromSource imports Docker images from a specified source file or directory
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.